@@ -1,6 +1,7 @@
 import benchmark
 
-import time, datetime
+import time
+import datetime
 
 class TimeTests(benchmark.Benchmark):
     label = 'datetime vs. time'
